@@ -164,7 +164,7 @@ class TestEpo(unittest.TestCase):
                     assert c[th : th + l] == "-" * l
                 th += l
 
-        for (a, b) in self.epo_records:
+        for a, b in self.epo_records:
             ca, cb = cigar_pairs[int(a.gabid)]
             ch(ca, a.cigar_iter(False))
             ch(cb, b.cigar_iter(False))
@@ -187,7 +187,7 @@ class TestEpo(unittest.TestCase):
             for s, t, q in zip(S, T, Q):
                 if not (cch(c1, th, th + s) and cch(c2, th, th + s)):
                     pdb.set_trace()
-                assert cch(c1, th, th + s) and cch(c2, th, th + s), f"{c1[th:th+s]} and {c2[th:th+s]}"
+                assert cch(c1, th, th + s) and cch(c2, th, th + s), f"{c1[th:th + s]} and {c2[th:th + s]}"
                 if t > q:
                     cch(c1, th + s, th + s + t) and c1[th + s : th + s + t] == "-" * t
                 else:
