@@ -33,9 +33,9 @@ class ScoringScheme:
         if gap2 is None:
             gap2 = gap1  # (scheme with gap1=gap2=None is legit)
         if isinstance(alphabet1, str):
-            alphabet1 = [ch for ch in alphabet1]
+            alphabet1 = list(alphabet1)
         if isinstance(alphabet2, str):
-            alphabet2 = [ch for ch in alphabet2]
+            alphabet2 = list(alphabet2)
         self.table = ones((text1_range, text2_range), typecode)
         self.table *= default
         self.gap_open = gap_open
@@ -97,9 +97,9 @@ class ScoringScheme:
             for b in self.alphabet2:
                 score = self._get_score((ord(a), ord(b)))
                 if isinstance(score, float):
-                    s = "%8.6f" % score
+                    s = f"{score:8.6f}"
                 else:
-                    s = "%s" % score
+                    s = f"{score}"
                 if len(s) + 1 > width:
                     width = len(s) + 1
         lines = []
@@ -113,7 +113,7 @@ class ScoringScheme:
             if isDna2:
                 s = b
             else:
-                s = "%02X" % ord(b)
+                s = f"{ord(b):02X}"
             line.append("%*s" % (width, s))
         lines.append(("".join(line)) + "\n")
         for a in self.alphabet1:
@@ -122,13 +122,13 @@ class ScoringScheme:
                 if isDna1:
                     line.append(a)
                 else:
-                    line.append("%02X" % ord(a))
+                    line.append(f"{ord(a):02X}")
             for b in self.alphabet2:
                 score = self._get_score((ord(a), ord(b)))
                 if isinstance(score, float):
-                    s = "%8.6f" % score
+                    s = f"{score:8.6f}"
                 else:
-                    s = "%s" % score
+                    s = f"{score}"
                 line.append("%*s" % (width, s))
             lines.append(("".join(line)) + "\n")
         return "".join(lines)
@@ -143,7 +143,7 @@ def read_scoring_scheme(f, gap_open, gap_extend, gap1="-", gap2=None, **kwargs):
     if isinstance(f, str):
         f = open(f)
         close_it = True
-    ss = build_scoring_scheme("".join([line for line in f]), gap_open, gap_extend, gap1=gap1, gap2=gap2, **kwargs)
+    ss = build_scoring_scheme("".join(list(f)), gap_open, gap_extend, gap1=gap1, gap2=gap2, **kwargs)
     if close_it:
         f.close()
     return ss
