@@ -12,13 +12,13 @@ test_nib = "test_data/seq_tests/test.nib"
 
 valid_seq = (
     "TGGAGGCATTTGTGATTCAATAGATGCAGAAAGAAACCTTCCTAGAGCTG"
-    + "GCGTTCTCTAACTAAAAGTGGAAAGTTCTGAGGAATGAGGACTGTTATAA"
-    + "ATCCCACCCCACACCGCACCTTCTCCAGGGAAGTTTCATGGCCGTGAAGA"
-    + "GGACAGAAAGTGAGAACCAAGATggaactgaataaacaagcttcacactg"
-    + "ttagtttccccatatgcttaccttcccacagatgccaaccttggaggcct"
-    + "aagaggcctagaatattatcctttgtctgatcatttctctacaaatttat"
-    + "tgttctttgttaagatgctacataagcccaaattctaaccacccctttga"
-    + "gttacccatcatcaagtttctcccatgtg"
+    "GCGTTCTCTAACTAAAAGTGGAAAGTTCTGAGGAATGAGGACTGTTATAA"
+    "ATCCCACCCCACACCGCACCTTCTCCAGGGAAGTTTCATGGCCGTGAAGA"
+    "GGACAGAAAGTGAGAACCAAGATggaactgaataaacaagcttcacactg"
+    "ttagtttccccatatgcttaccttcccacagatgccaaccttggaggcct"
+    "aagaggcctagaatattatcctttgtctgatcatttctctacaaatttat"
+    "tgttctttgttaagatgctacataagcccaaattctaaccacccctttga"
+    "gttacccatcatcaagtttctcccatgtg"
 )
 
 valid_seq_len = len(valid_seq)
