@@ -36,14 +36,14 @@ class FileBinnedArrayDir(Mapping):
 
     def __init__(self, dir):
         self.dir = dir
-        self.cache = dict()
+        self.cache = {}
 
     def __getitem__(self, key):
         value = None
         if key in self.cache:
             value = self.cache[key]
         else:
-            fname = os.path.join(self.dir, "%s.ba" % key)
+            fname = os.path.join(self.dir, f"{key}.ba")
             if os.path.exists(fname):
                 value = FileBinnedArray(open(fname))
                 self.cache[key] = value
@@ -63,7 +63,7 @@ def load_scores_wiggle(fname):
     Read a wiggle file and return a dict of BinnedArray objects keyed
     by chromosome.
     """
-    scores_by_chrom = dict()
+    scores_by_chrom = {}
     for chrom, pos, val in bx.wiggle.Reader(misc.open_compressed(fname)):
         if chrom not in scores_by_chrom:
             scores_by_chrom[chrom] = BinnedArray()
