@@ -18,7 +18,7 @@ def main():
         ints = [int(f) for f in line.split()]
         if max(ints) > len(table):
             raise ValueError("Alphabet size too large!")
-        print(str.join('', [table[i] for i in ints]))
+        print(str.join("", [table[i] for i in ints]))
 
 
 if __name__ == "__main__":
