@@ -17,7 +17,7 @@ def main():
     options, args = doc_optparse.parse(__doc__)
 
     try:
-        species = args[0].split(',')
+        species = args[0].split(",")
         nrequired = int(args[1])
     except Exception:
         doc_optparse.exit()
@@ -30,7 +30,7 @@ def main():
     for m in maf_reader:
         ref = m.components[0]
         # Does this alignment have enough of the required species
-        if nrequired <= len([comp for comp in m.components if comp.src.split('.')[0] in species]):
+        if nrequired <= len([comp for comp in m.components if comp.src.split(".")[0] in species]):
             if interval_start is None:
                 interval_start = ref.start
                 interval_end = ref.end
@@ -39,12 +39,12 @@ def main():
                     interval_end = ref.end
                 else:
                     if interval_end - interval_start >= MIN:
-                        print(ref.src.split('.')[1], interval_start, interval_end)
+                        print(ref.src.split(".")[1], interval_start, interval_end)
                     interval_start = ref.start
                     interval_end = ref.end
         else:
             if interval_start is not None and interval_end - interval_start >= MIN:
-                print(ref.src.split('.')[1], interval_start, interval_end)
+                print(ref.src.split(".")[1], interval_start, interval_end)
             interval_start = None
             interval_end = None
 
