@@ -12,12 +12,8 @@ usage: %prog n < maf_file
 import string
 import sys
 
-import psyco
-
 from bx.align import maf
 
-psyco.profile()
-
 
 def __main__():
     motif_len = int(sys.argv[1])
