@@ -7,4 +7,4 @@ Simple script to add a prefix to every line in a file.
 import sys
 
 for line in sys.stdin:
-    print(sys.argv[1] + line, end=' ')
+    print(sys.argv[1] + line, end=" ")
